#[repr(u8)]pub enum MessagePriority {
Low = 0,
Medium = 1,
High = 2,
Critical = 3,
}Variants
Low = 0
Message to be transferred with a low level of importance
Medium = 1
Message to be transferred with a medium level of importance
High = 2
Message to be transferred with a high level of importance
Critical = 3
Message to be transferred with a critical level of importance
Implementations